diff --git a/src/libs/Cohere/Generated/Cohere.CohereApi.Chatv2.g.cs b/src/libs/Cohere/Generated/Cohere.CohereApi.Chatv2.g.cs
index 5847d53..80cb4ab 100644
--- a/src/libs/Cohere/Generated/Cohere.CohereApi.Chatv2.g.cs
+++ b/src/libs/Cohere/Generated/Cohere.CohereApi.Chatv2.g.cs
@@ -129,7 +129,7 @@ partial void ProcessChatv2ResponseContent(
///
///
/// Used to select the [safety instruction](/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.
- /// When `NONE` is specified, the safety instruction will be omitted.
+ /// When `OFF` is specified, the safety instruction will be omitted.
/// Safety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.
/// **Note**: This parameter is only compatible with models [Command R 08-2024](/docs/command-r#august-2024-release), [Command R+ 08-2024](/docs/command-r-plus#august-2024-release) and newer.
/// Compatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments
diff --git a/src/libs/Cohere/Generated/Cohere.ICohereApi.Chatv2.g.cs b/src/libs/Cohere/Generated/Cohere.ICohereApi.Chatv2.g.cs
index 1c599f1..a771b00 100644
--- a/src/libs/Cohere/Generated/Cohere.ICohereApi.Chatv2.g.cs
+++ b/src/libs/Cohere/Generated/Cohere.ICohereApi.Chatv2.g.cs
@@ -45,7 +45,7 @@ public partial interface ICohereApi
///
///
/// Used to select the [safety instruction](/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.
- /// When `NONE` is specified, the safety instruction will be omitted.
+ /// When `OFF` is specified, the safety instruction will be omitted.
/// Safety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.
/// **Note**: This parameter is only compatible with models [Command R 08-2024](/docs/command-r#august-2024-release), [Command R+ 08-2024](/docs/command-r-plus#august-2024-release) and newer.
/// Compatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments
diff --git a/src/libs/Cohere/Generated/Cohere.Models.Chatv2Request.g.cs b/src/libs/Cohere/Generated/Cohere.Models.Chatv2Request.g.cs
index 62a9ad9..531d649 100644
--- a/src/libs/Cohere/Generated/Cohere.Models.Chatv2Request.g.cs
+++ b/src/libs/Cohere/Generated/Cohere.Models.Chatv2Request.g.cs
@@ -57,7 +57,7 @@ public sealed partial class Chatv2Request
///
/// Used to select the [safety instruction](/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.
- /// When `NONE` is specified, the safety instruction will be omitted.
+ /// When `OFF` is specified, the safety instruction will be omitted.
/// Safety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.
/// **Note**: This parameter is only compatible with models [Command R 08-2024](/docs/command-r#august-2024-release), [Command R+ 08-2024](/docs/command-r-plus#august-2024-release) and newer.
/// Compatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments
diff --git a/src/libs/Cohere/Generated/Cohere.Models.ToolMessageV2.g.cs b/src/libs/Cohere/Generated/Cohere.Models.ToolMessageV2.g.cs
index 69136e9..6c7a196 100644
--- a/src/libs/Cohere/Generated/Cohere.Models.ToolMessageV2.g.cs
+++ b/src/libs/Cohere/Generated/Cohere.Models.ToolMessageV2.g.cs
@@ -27,10 +27,9 @@ public sealed partial class ToolMessageV2
///
/// A single or list of outputs from a tool. The content should formatted as a JSON object string, or a list of tool content blocks
///
- [global::System.Text.Json.Serialization.JsonPropertyName("tool_content")]
+ [global::System.Text.Json.Serialization.JsonPropertyName("content")]
[global::System.Text.Json.Serialization.JsonConverter(typeof(global::Cohere.JsonConverters.OneOfJsonConverterFactory2))]
- [global::System.Text.Json.Serialization.JsonRequired]
- public required global::Cohere.OneOf> ToolContent { get; set; }
+ public global::Cohere.OneOf>? Content { get; set; }
///
/// Additional properties that are not explicitly defined in the schema
diff --git a/src/libs/Cohere/openapi.yaml b/src/libs/Cohere/openapi.yaml
index fcff267..f42a900 100644
--- a/src/libs/Cohere/openapi.yaml
+++ b/src/libs/Cohere/openapi.yaml
@@ -773,8 +773,8 @@ paths:
enum:
- CONTEXTUAL
- STRICT
- - NONE
- description: "Used to select the [safety instruction](/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.\nWhen `NONE` is specified, the safety instruction will be omitted.\n\nSafety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.\n\n**Note**: This parameter is only compatible with models [Command R 08-2024](/docs/command-r#august-2024-release), [Command R+ 08-2024](/docs/command-r-plus#august-2024-release) and newer.\n\nCompatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments\n"
+ - OFF
+ description: "Used to select the [safety instruction](/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.\nWhen `OFF` is specified, the safety instruction will be omitted.\n\nSafety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.\n\n**Note**: This parameter is only compatible with models [Command R 08-2024](/docs/command-r#august-2024-release), [Command R+ 08-2024](/docs/command-r-plus#august-2024-release) and newer.\n\nCompatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments\n"
max_tokens:
type: integer
description: "The maximum number of tokens the model will generate as part of the response. Note: Setting a low value may result in incomplete generations.\n"
@@ -9957,7 +9957,7 @@ components:
tool_call_id:
type: string
description: The id of the associated tool call that has provided the given content
- tool_content:
+ content:
oneOf:
- type: string
- type: array
diff --git a/src/libs/Cohere/Generated/Cohere.Models.Chatv2RequestSafetyMode.g.cs b/src/libs/Cohere/Generated/Cohere.Models.Chatv2RequestSafetyMode.g.cs
index efb9f77..d79e3eb 100644
--- a/src/libs/Cohere/Generated/Cohere.Models.Chatv2RequestSafetyMode.g.cs
+++ b/src/libs/Cohere/Generated/Cohere.Models.Chatv2RequestSafetyMode.g.cs
@@ -5,7 +5,7 @@ namespace Cohere
{
///
/// Used to select the [safety instruction](/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.
/// When `NONE` is specified, the safety instruction will be omitted.
/// Safety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.
/// **Note**: This parameter is only compatible with models [Command R 08-2024](/docs/command-r#august-2024-release), [Command R+ 08-2024](/docs/command-r-plus#august-2024-release) and newer.
/// Compatible Deployments: Cohere Platform, Azure, AWS Sagemaker/Bedrock, Private Deployments
@@ -23,7 +23,7 @@ public enum Chatv2RequestSafetyMode
///
///
///
- NONE,
+ OFF,
}
///
@@ -40,7 +40,7 @@ public static string ToValueString(this Chatv2RequestSafetyMode value)
{
Chatv2RequestSafetyMode.CONTEXTUAL => "CONTEXTUAL",
Chatv2RequestSafetyMode.STRICT => "STRICT",
- Chatv2RequestSafetyMode.NONE => "NONE",
+ Chatv2RequestSafetyMode.OFF => "OFF",
_ => throw new global::System.ArgumentOutOfRangeException(nameof(value), value, null),
};
}
@@ -53,7 +53,7 @@ public static string ToValueString(this Chatv2RequestSafetyMode value)
{
"CONTEXTUAL" => Chatv2RequestSafetyMode.CONTEXTUAL,
"STRICT" => Chatv2RequestSafetyMode.STRICT,
- "NONE" => Chatv2RequestSafetyMode.NONE,
+ "OFF" => Chatv2RequestSafetyMode.OFF,
_ => null,
};
}
@@ -5,7 +5,7 @@ namespace Cohere
///
/// Used to select the [safety instruction](/docs/safety-modes) inserted into the prompt. Defaults to `CONTEXTUAL`.
- /// When `NONE` is specified, the safety instruction will be omitted.
+ /// When `OFF` is specified, the safety instruction will be omitted.
/// Safety modes are not yet configurable in combination with `tools`, `tool_results` and `documents` parameters.
/// **Note**: This parameter is only compatible with models [Command R 08-2024](/docs/command-r#august-2024-release), [Command R+ 08-2024](/docs/command-r-plus#august-2024-release) and newer.